package websocket

import (
	"encoding/json"
	"github.com/charmbracelet/log"
	"github.com/gorilla/websocket"

	GoTomato "git.smsvc.net/pomodoro/GoTomato/pkg/models"
)

func sendClientCommand(conn *websocket.Conn, msg GoTomato.ClientCommand) {
	messageBytes, err := json.Marshal(msg)
	if err != nil {
		log.Error("Error marshalling!", "reason", err)
		return
	}

	err = conn.WriteMessage(websocket.TextMessage, messageBytes)
	if err != nil {
		log.Error("Write error!", "reason", err)
		return
	}
}

func SendCmd(conn *websocket.Conn, pwd string, cmd string) {
	message := GoTomato.ClientCommand{
		Command:  cmd,
		Password: pwd,
	}

	sendClientCommand(conn, message)
}

func Send_updateSettings(conn *websocket.Conn, pwd string, settings GoTomato.GoTomatoPomodoroConfig) {
	message := GoTomato.ClientCommand{
		Command:          "updateSettings",
		Password:         pwd,
		PomodoroSettings: settings,
	}

	sendClientCommand(conn, message)
}
